"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getTenants = exports.getPublicSettings = exports.getMeAuthorization = exports.getMe = exports.getEntitlements = exports.exchangeHostedLoginToken = exports.default = void 0;
var _config = _interopRequireDefault(require("../config"));
var _utils = require("./utils");
var _restApi = require("@frontegg/rest-api");
var _urls = require("../utils/common/urls");
/**
 * Send HTTP GET to frontegg domain public route to download the JWT public key
 */
const loadPublicKey = async () => {
  const response = await fetch(`${_config.default.baseUrl}${_urls.CommonUrls.WellKnown.jwks}`, {
    cache: 'force-cache'
  });
  const data = await response.json();
  return data.keys[0];
};

/**
 * Send HTTP post-request for Frontegg services to refresh token
 * by providing client's fe_ cookies
 */
const refreshTokenEmbedded = async headers => {
  return (0, _utils.Post)({
    url: `${_config.default.baseUrl}${_urls.CommonUrls.refreshToken.embedded}`,
    body: '{}',
    credentials: 'include',
    headers: (0, _utils.buildRequestHeaders)(headers)
  });
};

/**
 * Send HTTP post request for Frontegg services to refresh `hosted login` token
 * by providing client's fe_ as body with grant_type.
 */
const refreshTokenHostedLogin = async (headers, refresh_token, cliendId, clientSecret) => {
  return (0, _utils.Post)({
    url: `${_config.default.baseUrl}${_urls.CommonUrls.refreshToken.hosted}`,
    body: JSON.stringify({
      grant_type: 'refresh_token',
      refresh_token,
      client_id: cliendId,
      client_secret: clientSecret
    }),
    headers: (0, _utils.buildRequestHeaders)(headers)
  });
};

/**
 * Send HTTP post request for Frontegg services to exchange `hosted login` callback code
 */
const exchangeHostedLoginToken = async (headers, code, cliendId, clientSecret) => {
  return (0, _utils.Post)({
    url: `${_config.default.baseUrl}${_urls.CommonUrls.refreshToken.hosted}`,
    body: JSON.stringify({
      redirect_uri: `${_config.default.appUrl}/oauth/callback`,
      grant_type: 'authorization_code',
      code,
      client_id: cliendId,
      client_secret: clientSecret
      // code_verifier
    }),
    headers: (0, _utils.buildRequestHeaders)(headers)
  });
};

/**
 *
 * @param headers
 */
exports.exchangeHostedLoginToken = exchangeHostedLoginToken;
const getMe = async headers => {
  const headersToSend = (0, _utils.buildRequestHeaders)(headers);
  const res = await (0, _utils.Get)({
    url: `${_config.default.baseUrl}/frontegg${_restApi.fronteggUsersUrl}`,
    headers: headersToSend
  });
  return (0, _utils.parseHttpResponse)(res);
};

/**
 *
 * @param headers
 */
exports.getMe = getMe;
const getEntitlements = async headers => {
  const headersToSend = (0, _utils.buildRequestHeaders)(headers);
  const res = await (0, _utils.Get)({
    url: `${_config.default.baseUrl}${_restApi.fronteggEntitlementsV2Url}`,
    headers: headersToSend
  });
  return (0, _utils.parseHttpResponse)(res);
};

/**
 *
 * @param headers
 */
exports.getEntitlements = getEntitlements;
const getTenants = async headers => {
  const res = await (0, _utils.Get)({
    url: `${_config.default.baseUrl}/frontegg${_restApi.fronteggTenantsV3Url}`,
    headers: (0, _utils.buildRequestHeaders)(headers)
  });
  return (0, _utils.parseHttpResponse)(res);
};

/**
 *
 * @param headers
 */
exports.getTenants = getTenants;
const getMeAuthorization = async headers => {
  const res = await (0, _utils.Get)({
    //TODO: replace this with rest/api route
    url: `${_config.default.baseUrl}/frontegg/identity/resources/users/v1/me/authorization`,
    headers: (0, _utils.buildRequestHeaders)(headers)
  });
  return (0, _utils.parseHttpResponse)(res);
};
exports.getMeAuthorization = getMeAuthorization;
const getPublicSettings = async headers => {
  const res = await (0, _utils.Get)({
    //TODO: export the route url from rest-api and import from there
    url: `${_config.default.baseUrl}/frontegg/tenants/resources/account-settings/v1/public`,
    headers: (0, _utils.buildRequestHeaders)(headers)
  });
  return (0, _utils.parseHttpResponse)(res);
};
exports.getPublicSettings = getPublicSettings;
var _default = exports.default = {
  loadPublicKey,
  refreshTokenEmbedded,
  refreshTokenHostedLogin,
  getMe,
  getTenants,
  getPublicSettings,
  getEntitlements,
  exchangeHostedLoginToken
};
//# sourceMappingURL=index.js.map