export interface BuildRouteResult {
    asPath: string;
    asUrl: URL;
}
/**
 * Builds a login route with a redirect URL encoded as a query parameter.
 *
 *  @param {string} redirectUrl - The URL to redirect to after successful login.
 *  @param {URLSearchParams} searchParams - optional The URL search Params to preserve to log in
 *  @param {string} baseUrl - optional The login base URL the user will be redirected to (default .env.local FRONTEGG_APP_URL)
 *  @returns {BuildRouteResult} An object containing the generated login route and URL.
 *
 *  @throws {TypeError} If redirectUrl is not a string.
 */
export declare function buildLoginRoute(redirectUrl: string, searchParams?: URLSearchParams, baseUrl?: string): BuildRouteResult;
/**
 * Builds a HostedLogin's logout route with a redirect URL encoded as a query parameter.
 *
 *  @param {string} redirectUrl - The URL to redirect to after successful login.
 *  @param {string} baseUrl - The frontegg domain url
 *  @returns {BuildRouteResult} An object containing the generated login route and URL.
 *
 *  @throws {TypeError} If redirectUrl is not a string.
 */
export declare function buildLogoutRoute(redirectUrl: string, baseUrl: string): BuildRouteResult;
