"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildLoginRoute = buildLoginRoute;
exports.buildLogoutRoute = buildLogoutRoute;
var _config = _interopRequireDefault(require("../config"));
/**
 * Builds a login route with a redirect URL encoded as a query parameter.
 *
 *  @param {string} redirectUrl - The URL to redirect to after successful login.
 *  @param {URLSearchParams} searchParams - optional The URL search Params to preserve to log in
 *  @param {string} baseUrl - optional The login base URL the user will be redirected to (default .env.local FRONTEGG_APP_URL)
 *  @returns {BuildRouteResult} An object containing the generated login route and URL.
 *
 *  @throws {TypeError} If redirectUrl is not a string.
 */
function buildLoginRoute(redirectUrl, searchParams, baseUrl = _config.default.appUrl) {
  const asPath = `${baseUrl}/account/login?redirectUrl=${encodeURIComponent(redirectUrl)}${searchParams ? `&${searchParams.toString()}` : ''}`;
  const asUrl = new URL(asPath);
  return {
    asPath,
    asUrl
  };
}

/**
 * Builds a HostedLogin's logout route with a redirect URL encoded as a query parameter.
 *
 *  @param {string} redirectUrl - The URL to redirect to after successful login.
 *  @param {string} baseUrl - The frontegg domain url
 *  @returns {BuildRouteResult} An object containing the generated login route and URL.
 *
 *  @throws {TypeError} If redirectUrl is not a string.
 */
function buildLogoutRoute(redirectUrl, baseUrl) {
  const asPath = `${baseUrl}/oauth/logout?post_logout_redirect_uri=${encodeURIComponent(redirectUrl)}`;
  const asUrl = new URL(asPath, baseUrl);
  return {
    asPath,
    asUrl
  };
}
//# sourceMappingURL=urls.js.map