interface GetRequestOptions {
    url: string;
    credentials?: RequestCredentials;
    headers?: HeadersInit;
}
export declare const Get: ({ url, credentials, headers }: GetRequestOptions) => Promise<Response>;
interface PostRequestOptions extends GetRequestOptions {
    body: string;
}
export declare const Post: ({ url, credentials, headers, body }: PostRequestOptions) => Promise<Response>;
/**
 * NodeJS 18 start using undici as http request handler,
 * undici http request does not accept invalid headers
 * for more details see:
 * https://github.com/nodejs/undici/blob/2b260c997ad4efe4ed2064b264b4b546a59e7a67/lib/core/request.js#L282
 * @param headers
 */
export declare function removeInvalidHeaders(headers: Record<string, string>): {
    [x: string]: string;
};
/**
 * These headers are used to identify the tenant for login per tenant feature
 */
export declare const CUSTOM_LOGIN_HEADER = "frontegg-login-alias";
export declare const FRONTEGG_FORWARD_IP_HEADER = "x-frontegg-forwarded-for";
export declare const FRONTEGG_HEADERS_VERIFIER_HEADER = "x-frontegg-headers-verifier";
export declare const FRONTEGG_APPLICATION_ID_HEADER = "frontegg-requested-application-id";
export declare const FRONTEGG_VENDOR_ID_HEADER = "frontegg-vendor-id";
/**
 * Build fetch request headers, remove invalid http headers
 * @param headers - Incoming request headers
 */
export declare function buildRequestHeaders(headers: Record<string, any>): Record<string, string>;
/**
 * Return parsed json response if http status code = 200
 * @param res
 */
export declare const parseHttpResponse: <T>(res: Response) => Promise<T | undefined>;
/**
 * Checks if the given path should be forwarded to the Next.js server middleware.
 *
 *
 * @param {string} path - The path to check for authentication API routes.
 * @returns {boolean} Returns true if the path is a frontegg authentication API route or ends with '/postlogin' or '/prelogin'; otherwise, returns false.
 */
export declare function isMiddlewarePath(path: string): boolean;
/**
 * Extracts the real client IP address from a raw IP string or array.
 *
 * If the input contains multiple IPs (e.g., from the `x-forwarded-for` header),
 * it returns only the first IP, which typically represents the real client.
 *
 * @param rawIp - A single IP string or an array of IPs.
 * @returns The first IP address as a string, or undefined if not available.
 */
export declare function getClientIp(rawIp?: string | string[] | null): string | undefined;
export {};
