"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Post = exports.Get = exports.FRONTEGG_VENDOR_ID_HEADER = exports.FRONTEGG_HEADERS_VERIFIER_HEADER = exports.FRONTEGG_FORWARD_IP_HEADER = exports.FRONTEGG_APPLICATION_ID_HEADER = exports.CUSTOM_LOGIN_HEADER = void 0;
exports.buildRequestHeaders = buildRequestHeaders;
exports.getClientIp = getClientIp;
exports.isMiddlewarePath = isMiddlewarePath;
exports.parseHttpResponse = void 0;
exports.removeInvalidHeaders = removeInvalidHeaders;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _config = _interopRequireDefault(require("../config"));
var _sdkVersion = _interopRequireDefault(require("../sdkVersion"));
var _package = _interopRequireDefault(require("next/package.json"));
var _restApi = require("@frontegg/rest-api");
var _constants = require("../utils/common/constants");
const Get = ({
  url,
  credentials = 'include',
  headers
}) => fetch(url, {
  method: 'GET',
  credentials,
  headers
});
exports.Get = Get;
const Post = ({
  url,
  credentials = 'include',
  headers,
  body
}) => fetch(url, {
  method: 'POST',
  credentials,
  headers,
  body
});

/**
 * NodeJS 18 start using undici as http request handler,
 * undici http request does not accept invalid headers
 * for more details see:
 * https://github.com/nodejs/undici/blob/2b260c997ad4efe4ed2064b264b4b546a59e7a67/lib/core/request.js#L282
 * @param headers
 */
exports.Post = Post;
function removeInvalidHeaders(headers) {
  const newHeaders = (0, _extends2.default)({}, headers);
  Object.keys(newHeaders).forEach(key => {
    const val = headers[key];
    if (val && typeof val === 'object' && !Array.isArray(val)) {
      delete newHeaders[key];
    } else if (_constants.headerCharRegex.exec(val) !== null) {
      delete newHeaders[key];
    } else if (val === undefined || val === null) {
      delete newHeaders[key];
    } else if (key.length === 10 && key === 'connection') {
      delete newHeaders[key];
    }
  });
  return newHeaders;
}

/**
 * These headers are used to identify the tenant for login per tenant feature
 */
const CUSTOM_LOGIN_HEADER = exports.CUSTOM_LOGIN_HEADER = 'frontegg-login-alias';
const FRONTEGG_FORWARD_IP_HEADER = exports.FRONTEGG_FORWARD_IP_HEADER = 'x-frontegg-forwarded-for';
const FRONTEGG_HEADERS_VERIFIER_HEADER = exports.FRONTEGG_HEADERS_VERIFIER_HEADER = 'x-frontegg-headers-verifier';
const FRONTEGG_APPLICATION_ID_HEADER = exports.FRONTEGG_APPLICATION_ID_HEADER = 'frontegg-requested-application-id';
const FRONTEGG_VENDOR_ID_HEADER = exports.FRONTEGG_VENDOR_ID_HEADER = 'frontegg-vendor-id';

/**
 * Build fetch request headers, remove invalid http headers
 * @param headers - Incoming request headers
 */
function buildRequestHeaders(headers) {
  let cookie = headers['cookie'];
  if (cookie != null && typeof cookie === 'string') {
    cookie = cookie.replace(/fe_session-[^=]*=[^;]*$/, '').replace(/fe_session-[^=]*=[^;]*;/, '');
    if (_config.default.rewriteCookieByAppId && _config.default.appId) {
      cookie = cookie.split(';').filter(cookieStr => !cookieStr.trim().startsWith(`fe_refresh_${_config.default.clientId.replace('-', '')}`)).join(';');
      cookie = cookie.replace(`fe_refresh_${_config.default.appId.replace('-', '')}`, `fe_refresh_${_config.default.clientId.replace('-', '')}`);
    }
  }
  if (cookie != null && typeof cookie === 'object') {
    cookie = Object.entries(cookie).filter(([key]) => {
      if (_config.default.rewriteCookieByAppId && _config.default.appId) {
        return key !== `fe_refresh_${_config.default.clientId.replace('-', '')}`;
      }
      return true;
    }).map(([key, value]) => {
      if (_config.default.rewriteCookieByAppId && _config.default.appId && key === `fe_refresh_${_config.default.appId.replace('-', '')}`) {
        return `fe_refresh_${_config.default.clientId.replace('-', '')}=${value}`;
      } else {
        return `${key}=${value}`;
      }
    }).join('; ');
  }
  const preparedHeaders = {
    authorization: headers['authorization'],
    'accept-encoding': headers['accept-encoding'],
    'accept-language': headers['accept-language'],
    accept: headers['accept'],
    'content-type': 'application/json',
    origin: _config.default.baseUrl,
    cookie,
    'user-agent': headers['user-agent'],
    'cache-control': headers['cache-control'],
    'x-frontegg-framework': `next@${_package.default.version}`,
    'x-frontegg-sdk': `@frontegg/nextjs@${_sdkVersion.default.version}`
  };
  if (headers[FRONTEGG_APPLICATION_ID_HEADER]) {
    preparedHeaders[FRONTEGG_APPLICATION_ID_HEADER] = headers[FRONTEGG_APPLICATION_ID_HEADER];
  }
  const clientIp = getClientIp(headers[FRONTEGG_FORWARD_IP_HEADER] || headers['cf-connecting-ip'] || headers['x-forwarded-for']);
  if (clientIp && _config.default.shouldForwardIp) {
    var _config$sharedSecret;
    preparedHeaders[FRONTEGG_FORWARD_IP_HEADER] = clientIp;
    preparedHeaders[FRONTEGG_HEADERS_VERIFIER_HEADER] = (_config$sharedSecret = _config.default.sharedSecret) != null ? _config$sharedSecret : '';
    preparedHeaders[FRONTEGG_VENDOR_ID_HEADER] = _config.default.clientId;
  }
  if (headers[CUSTOM_LOGIN_HEADER]) {
    preparedHeaders[CUSTOM_LOGIN_HEADER] = headers[CUSTOM_LOGIN_HEADER];
  }
  return removeInvalidHeaders((0, _extends2.default)({}, preparedHeaders));
}

/**
 * Return parsed json response if http status code = 200
 * @param res
 */
const parseHttpResponse = async res => {
  if (!res.ok) {
    return undefined;
  }
  return await res.json();
};

/**
 * Checks if the given path should be forwarded to the Next.js server middleware.
 *
 *
 * @param {string} path - The path to check for authentication API routes.
 * @returns {boolean} Returns true if the path is a frontegg authentication API route or ends with '/postlogin' or '/prelogin'; otherwise, returns false.
 */
exports.parseHttpResponse = parseHttpResponse;
function isMiddlewarePath(path) {
  let isAuthPath = _restApi.fronteggAuthApiRoutesRegex.find(pathRegex => {
    if (typeof pathRegex === 'string') {
      return pathRegex === path;
    } else {
      return new RegExp(pathRegex).test(path);
    }
  }) != null;

  // if(!isAuthPath){
  //   isAuthPath = /^\/identity\/resources\/auth\/v[0-9]*\/user\/sso\/[^\/]*\/postlogin$/g.test(path)
  // }
  // if(!isAuthPath){
  //   isAuthPath = /^\/identity\/resources\/auth\/v[0-9]*\/passwordless\/[^\/]*\/prelogin$/g.test(path)
  // }
  // if(!isAuthPath){
  //   isAuthPath = /^\/identity\/resources\/auth\/v[0-9]*\/[^\/]*\/prelogin$/g.test(path)
  // }

  if (!isAuthPath) {
    const isSocialLoginPath = /^\/identity\/resources\/auth\/v[0-9]*\/user\/sso\/default\/[^\/]*\/prelogin$/.test(path);
    isAuthPath = (path.endsWith('/postlogin') || path.endsWith('/prelogin')) && !isSocialLoginPath;
  }
  return isAuthPath;
}

/**
 * Extracts the real client IP address from a raw IP string or array.
 *
 * If the input contains multiple IPs (e.g., from the `x-forwarded-for` header),
 * it returns only the first IP, which typically represents the real client.
 *
 * @param rawIp - A single IP string or an array of IPs.
 * @returns The first IP address as a string, or undefined if not available.
 */
function getClientIp(rawIp) {
  if (!rawIp) return undefined;
  const ip = Array.isArray(rawIp) ? rawIp[0] : rawIp;
  return ip.split(',')[0].trim();
}
//# sourceMappingURL=utils.js.map