"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.resetGlobalCustomLoginAppUrl = exports.getTenantAliasFromHeaders = exports.getAppUrlForCustomLoginWithSubdomain = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _api = require("../api");
var _utils = require("../api/utils");
var _helpers = require("./helpers");
/**
 * get the tenant alias from the request headers with the host and subdomain index
 * @param headers - the request headers
 * @param subDomainIndex - the subdomain index to specify the tenant sub-domain
 * @returns the alias for custom login with subdomain or undefined if not exist
 */
const getTenantAliasFromHeaders = (headers, subDomainIndex) => {
  var _headers$host;
  return headers == null || (_headers$host = headers.host) == null || (_headers$host = _headers$host.split('.')) == null || (_headers$host = _headers$host.slice(0, -2)) == null ? void 0 : _headers$host[subDomainIndex];
};

/**
 * set the global.customLoginAppUrl to undefined in order to allow switching from tenant to vendor app
 */
exports.getTenantAliasFromHeaders = getTenantAliasFromHeaders;
const resetGlobalCustomLoginAppUrl = () => {
  global.customLoginAppUrl = undefined;
};

/**
 * get the app url for custom login with subdomain and set it to the global customLoginAppUrl
 * @param subDomainIndex - the index of the subdomain in the host
 * @returns Promise of string or undefined, the app url for custom login with subdomain or undefined if the sub-domain index/app url/alias is not exist
 * @sideEffect - set the global.customLoginAppUrl to the app url for custom login with subdomain */
exports.resetGlobalCustomLoginAppUrl = resetGlobalCustomLoginAppUrl;
const getAppUrlForCustomLoginWithSubdomain = async subDomainIndex => {
  if (subDomainIndex === undefined) {
    return undefined;
  }
  const headers = await (0, _helpers.getAppHeaders)();
  const alias = getTenantAliasFromHeaders(headers, subDomainIndex);
  if (!alias) {
    resetGlobalCustomLoginAppUrl();
    return undefined;
  }
  const requestHeaders = (0, _extends2.default)({}, headers, {
    [_utils.CUSTOM_LOGIN_HEADER]: alias
  });
  const res = await (0, _api.getPublicSettings)(requestHeaders).catch(() => undefined);
  const subDomainAppUrl = res == null ? void 0 : res.applicationUrl;
  if (!subDomainAppUrl) {
    resetGlobalCustomLoginAppUrl();
    return undefined;
  }
  global.customLoginAppUrl = subDomainAppUrl;
  return subDomainAppUrl;
};
exports.getAppUrlForCustomLoginWithSubdomain = getAppUrlForCustomLoginWithSubdomain;
//# sourceMappingURL=getAppUrlForCustomLoginWithSubdomain.js.map