"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAppSession = exports.getAppHeaders = void 0;
exports.getAppUserSession = getAppUserSession;
exports.getAppUserTokens = getAppUserTokens;
exports.handleOptionalPromiseObject = handleOptionalPromiseObject;
var _headers = require("next/headers");
var _cookies = _interopRequireDefault(require("../utils/cookies"));
var _createSession = _interopRequireDefault(require("../utils/createSession"));
var _encryption = _interopRequireDefault(require("../utils/encryption"));
/**
 * Support for Next.js 15 breaking changes, where props.params is now a promise-based function
 * for more info: https://nextjs.org/docs/messages/sync-dynamic-apis
 * @param obj
 * @param key
 */
async function handleOptionalPromiseObject(obj, key) {
  let value;
  if (typeof obj[key] === 'function') {
    var _obj$key;
    // In case props.params is now a promise-based function
    value = await (obj == null || (_obj$key = obj[key]) == null ? void 0 : _obj$key.call(obj));
  } else {
    // If props.params is still an object
    value = obj == null ? void 0 : obj[key];
  }
  return value;
}

/**
 * Support for Next.js 15 breaking changes, where cookies() are now promise-based functions
 * for more info: https://nextjs.org/docs/messages/sync-dynamic-apis
 * @param func
 */
async function getRequestCookies() {
  let value = (0, _headers.cookies)();

  // noinspection SuspiciousTypeOfGuard
  if (value instanceof Promise) {
    return await value;
  }
  return value;
}

/**
 * Support for Next.js 15 breaking changes, where cookies() are now promise-based functions
 * for more info: https://nextjs.org/docs/messages/sync-dynamic-apis
 * @param func
 */
async function getRequestHeaders() {
  let value = (0, _headers.headers)();

  // noinspection SuspiciousTypeOfGuard
  if (value instanceof Promise) {
    return await value;
  }
  return value;
}
const getCookie = async () => {
  const allCookies = (await getRequestCookies()).getAll();
  return _cookies.default.parseCookieFromArray(allCookies);
};
const getAppSession = async () => {
  const cookies = await getCookie();
  return (0, _createSession.default)(cookies, _encryption.default);
};
exports.getAppSession = getAppSession;
const getAppHeaders = async () => {
  const reqHeaders = {};
  (await getRequestHeaders()).forEach((value, key) => reqHeaders[key] = value);
  return reqHeaders;
};
exports.getAppHeaders = getAppHeaders;
async function getAppUserSession() {
  const session = await getAppSession();
  return session == null ? void 0 : session.user;
}
async function getAppUserTokens() {
  const session = await getAppSession();
  if (!session) {
    return undefined;
  }
  return {
    accessToken: session.accessToken,
    refreshToken: session.refreshToken
  };
}
//# sourceMappingURL=helpers.js.map