"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createSessionFromAccessToken = createSessionFromAccessToken;
exports.getAfterAuthRedirectUrl = void 0;
exports.getTokensFromCookie = getTokensFromCookie;
var _jwt = _interopRequireDefault(require("../utils/jwt"));
var _encryption = _interopRequireDefault(require("../utils/encryption"));
async function createSessionFromAccessToken(data) {
  var _data$accessToken, _data$refreshToken;
  const accessToken = (_data$accessToken = data.accessToken) != null ? _data$accessToken : data.access_token;
  const refreshToken = (_data$refreshToken = data.refreshToken) != null ? _data$refreshToken : data.refresh_token;
  const {
    payload: decodedJwt
  } = await _jwt.default.verify(accessToken);
  decodedJwt.expiresIn = Math.floor((decodedJwt.exp * 1000 - Date.now()) / 1000);
  const tokens = {
    accessToken,
    refreshToken
  };
  const session = await _encryption.default.sealTokens(tokens, decodedJwt.exp);
  return [session, decodedJwt, refreshToken];
}
async function getTokensFromCookie(cookie) {
  if (!cookie) {
    return undefined;
  }
  return await _encryption.default.unsealTokens(cookie);
}
const getAfterAuthRedirectUrl = queryParams => {
  const redirectPath = queryParams.redirectUrl;
  const query = new URLSearchParams();
  for (const [key, value] of Object.entries(queryParams)) {
    if (key !== 'redirectUrl' && value !== undefined) {
      query.append(key, String(value));
    }
  }
  const redirectUrl = query.toString() ? `${redirectPath}?${query.toString()}` : redirectPath;
  return `${window.location.origin}${redirectUrl}`;
};
exports.getAfterAuthRedirectUrl = getAfterAuthRedirectUrl;
//# sourceMappingURL=helpers.js.map