"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useLogoutHostedLogin = void 0;
var _reactHooks = require("@frontegg/react-hooks");
var _restApi = require("@frontegg/rest-api");
var _urls = require("../api/urls");
/**
 * Hook to logout client side for hosted login
 * @returns {Function} logout function to be used in the client side for hosted login
 * @param redirectUrl - The URL to redirect to after successful logout will be window.location.href by default.
 * @deprecated use `const { logout } = useLoginActions();`
 */

const useLogoutHostedLogin = () => {
  const {
    appName
  } = (0, _reactHooks.useRootState)();
  const {
    logout
  } = (0, _reactHooks.useLoginActions)();
  return redirectUrl => {
    var _ContextHolder$for$ge;
    const contextBaseUrl = (_ContextHolder$for$ge = _restApi.ContextHolder.for(appName).getContext()) == null ? void 0 : _ContextHolder$for$ge.baseUrl;
    const baseUrl = typeof contextBaseUrl === 'function' ? contextBaseUrl('') : contextBaseUrl;
    const finalRedirectUrl = redirectUrl != null ? redirectUrl : window.location.href;
    const logoutRoute = (0, _urls.buildLogoutRoute)(finalRedirectUrl, baseUrl).asPath;
    logout(() => {
      window.location.href = logoutRoute;
    });
  };
};
exports.useLogoutHostedLogin = useLogoutHostedLogin;
//# sourceMappingURL=hooks.js.map