"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EnvVariables", {
  enumerable: true,
  get: function () {
    return _constants.EnvVariables;
  }
});
exports.default = void 0;
var _helpers = require("./helpers");
var _constants = require("./constants");
var _errors = require("../utils/errors");
const setupEnvVariables = {
  FRONTEGG_APP_URL: process.env.FRONTEGG_APP_URL,
  FRONTEGG_BASE_URL: process.env.FRONTEGG_BASE_URL,
  FRONTEGG_TEST_URL: process.env.FRONTEGG_TEST_URL,
  FRONTEGG_CLIENT_ID: process.env.FRONTEGG_CLIENT_ID,
  FRONTEGG_APP_ID: process.env.FRONTEGG_APP_ID,
  FRONTEGG_REWRITE_COOKIE_BY_APP_ID: process.env.FRONTEGG_REWRITE_COOKIE_BY_APP_ID,
  FRONTEGG_CLIENT_SECRET: process.env.FRONTEGG_CLIENT_SECRET,
  FRONTEGG_SHARED_SECRET: process.env.FRONTEGG_SHARED_SECRET,
  FRONTEGG_ENCRYPTION_PASSWORD: process.env.FRONTEGG_ENCRYPTION_PASSWORD,
  FRONTEGG_COOKIE_NAME: process.env.FRONTEGG_COOKIE_NAME,
  FRONTEGG_COOKIE_DOMAIN: process.env.FRONTEGG_COOKIE_DOMAIN,
  FRONTEGG_COOKIE_SAME_SITE: process.env.FRONTEGG_COOKIE_SAME_SITE,
  FRONTEGG_JWT_PUBLIC_KEY: process.env.FRONTEGG_JWT_PUBLIC_KEY,
  FRONTEGG_SECURE_JWT_ENABLED: process.env.FRONTEGG_SECURE_JWT_ENABLED,
  FRONTEGG_FORWARD_IP: process.env.FRONTEGG_FORWARD_IP,
  FRONTEGG_SSG_EXPORT: process.env.FRONTEGG_SSG_EXPORT,
  DISABLE_INITIAL_PROPS_REFRESH_TOKEN: process.env.DISABLE_INITIAL_PROPS_REFRESH_TOKEN,
  VERCEL: process.env.VERCEL,
  VERCEL_URL: process.env.VERCEL_URL
};
class Config {
  constructor() {
    this.fronteggAppOptions = {};
    if (!this.isSSGExport) {
      if (typeof window === 'undefined') {
        this.validatePassword();
      }
    }
  }
  get isSSGExport() {
    var _getEnvOrDefault;
    const isSSGExport = (_getEnvOrDefault = (0, _helpers.getEnvOrDefault)(_constants.EnvVariables.FRONTEGG_SSG_EXPORT, setupEnvVariables.FRONTEGG_SSG_EXPORT)) != null ? _getEnvOrDefault : 'false';
    return isSSGExport === 'true';
  }
  get appUrl() {
    return (0, _helpers.generateAppUrl)();
  }
  get testUrl() {
    return (0, _helpers.getEnvOrDefault)(_constants.EnvVariables.FRONTEGG_TEST_URL, setupEnvVariables.FRONTEGG_TEST_URL);
  }
  get baseUrl() {
    const baseUrl = (0, _helpers.getEnvOrDefault)(_constants.EnvVariables.FRONTEGG_BASE_URL, setupEnvVariables.FRONTEGG_BASE_URL);
    if (!baseUrl) {
      throw new _errors.FronteggEnvNotFound(_constants.EnvVariables.FRONTEGG_BASE_URL);
    }
    if (baseUrl.endsWith('/')) {
      return baseUrl.slice(0, -1);
    }
    return baseUrl;
  }
  get baseUrlHost() {
    return new URL(this.baseUrl).hostname;
  }
  get clientId() {
    var _EnvVariables$FRONTEG;
    const clientId = (0, _helpers.getEnv)((_EnvVariables$FRONTEG = _constants.EnvVariables.FRONTEGG_CLIENT_ID) != null ? _EnvVariables$FRONTEG : setupEnvVariables.FRONTEGG_CLIENT_ID);
    if (!clientId) {
      throw new _errors.FronteggEnvNotFound(_constants.EnvVariables.FRONTEGG_CLIENT_ID);
    }
    return clientId;
  }
  get appId() {
    return (0, _helpers.getEnvOrDefault)(_constants.EnvVariables.FRONTEGG_APP_ID, setupEnvVariables.FRONTEGG_APP_ID);
  }
  get rewriteCookieByAppId() {
    var _setupEnvVariables$FR;
    return (0, _helpers.getEnvOrDefault)(_constants.EnvVariables.FRONTEGG_REWRITE_COOKIE_BY_APP_ID, (_setupEnvVariables$FR = setupEnvVariables.FRONTEGG_REWRITE_COOKIE_BY_APP_ID) != null ? _setupEnvVariables$FR : 'false') === 'true';
  }
  get clientSecret() {
    let clientSecret;
    try {
      var _getEnv;
      clientSecret = (_getEnv = (0, _helpers.getEnv)(_constants.EnvVariables.FRONTEGG_CLIENT_SECRET)) != null ? _getEnv : setupEnvVariables.FRONTEGG_CLIENT_SECRET;
    } catch (e) {
      clientSecret = setupEnvVariables.FRONTEGG_CLIENT_SECRET;
    }
    if (this.secureJwtEnabled && !clientSecret) {
      throw new _errors.InvalidFronteggEnv(_constants.EnvVariables.FRONTEGG_CLIENT_SECRET, 'Client secret is required when secure JWT is enabled');
    }
    return clientSecret;
  }
  get sharedSecret() {
    let sharedSecret;
    try {
      var _getEnv2;
      sharedSecret = (_getEnv2 = (0, _helpers.getEnv)(_constants.EnvVariables.FRONTEGG_SHARED_SECRET)) != null ? _getEnv2 : setupEnvVariables.FRONTEGG_SHARED_SECRET;
    } catch (e) {
      sharedSecret = setupEnvVariables.FRONTEGG_SHARED_SECRET;
    }
    return sharedSecret;
  }
  get shouldForwardIp() {
    var _setupEnvVariables$FR2;
    return (0, _helpers.getEnvOrDefault)(_constants.EnvVariables.FRONTEGG_FORWARD_IP, (_setupEnvVariables$FR2 = setupEnvVariables.FRONTEGG_FORWARD_IP) != null ? _setupEnvVariables$FR2 : 'false') === 'true';
  }
  get jwtPublicKeyJson() {
    var _getEnv3;
    return (_getEnv3 = (0, _helpers.getEnv)(_constants.EnvVariables.FRONTEGG_JWT_PUBLIC_KEY)) != null ? _getEnv3 : setupEnvVariables.FRONTEGG_JWT_PUBLIC_KEY;
  }
  get secureJwtEnabled() {
    var _setupEnvVariables$FR3;
    return (0, _helpers.getEnvOrDefault)(_constants.EnvVariables.FRONTEGG_SECURE_JWT_ENABLED, (_setupEnvVariables$FR3 = setupEnvVariables.FRONTEGG_SECURE_JWT_ENABLED) != null ? _setupEnvVariables$FR3 : 'false') == 'true';
  }
  get cookieName() {
    var _setupEnvVariables$FR4;
    const cookieNameEnv = (0, _helpers.getEnvOrDefault)(_constants.EnvVariables.FRONTEGG_COOKIE_NAME, (_setupEnvVariables$FR4 = setupEnvVariables.FRONTEGG_COOKIE_NAME) != null ? _setupEnvVariables$FR4 : 'fe_session');
    if (this.rewriteCookieByAppId && this.appId) {
      return `${cookieNameEnv}-${this.appId.replace(/-/g, '')}`;
    } else {
      return `${cookieNameEnv}-${this.clientId.replace(/-/g, '')}`;
    }
  }
  get cookieDomain() {
    var _setupEnvVariables$FR5;
    return (0, _helpers.getEnvOrDefault)(_constants.EnvVariables.FRONTEGG_COOKIE_DOMAIN, (_setupEnvVariables$FR5 = setupEnvVariables.FRONTEGG_COOKIE_DOMAIN) != null ? _setupEnvVariables$FR5 : (0, _helpers.generateCookieDomain)(this.appUrl));
  }
  get cookieSameSite() {
    var _setupEnvVariables$FR6;
    let sameSite = (0, _helpers.getEnvOrDefault)(_constants.EnvVariables.FRONTEGG_COOKIE_SAME_SITE, (_setupEnvVariables$FR6 = setupEnvVariables.FRONTEGG_COOKIE_SAME_SITE) != null ? _setupEnvVariables$FR6 : 'none');
    switch (sameSite) {
      case 'true':
        return 'strict';
      case 'false':
        return 'none';
      case 'lax':
      case 'strict':
      case 'none':
        return sameSite;
      default:
        return 'none';
    }
  }
  get authRoutes() {
    var _this$fronteggAppOpti, _this$fronteggAppOpti2;
    return (_this$fronteggAppOpti = (_this$fronteggAppOpti2 = this.fronteggAppOptions) == null || (_this$fronteggAppOpti2 = _this$fronteggAppOpti2.authOptions) == null ? void 0 : _this$fronteggAppOpti2.routes) != null ? _this$fronteggAppOpti : {};
  }
  validatePassword() {
    const passwordMaps = this.password;
    for (let key of Object.keys(passwordMaps)) {
      const password = passwordMaps[key];
      if (!password.match(/[0-9A-Fa-f]{6}/g) || password.length !== 64) {
        throw new _errors.InvalidFronteggEnv(_constants.EnvVariables.FRONTEGG_ENCRYPTION_PASSWORD, `Hex string.\n\nFor quick password generation use the following command:\nnode -e "console.log(crypto.randomBytes(32).toString('hex'))"`);
      }
    }
  }
  get password() {
    const encryptionPasswordEnv = (0, _helpers.getEnvOrDefault)(_constants.EnvVariables.FRONTEGG_ENCRYPTION_PASSWORD, setupEnvVariables.FRONTEGG_ENCRYPTION_PASSWORD);
    if (!encryptionPasswordEnv) {
      throw new _errors.InvalidFronteggEnv(_constants.EnvVariables.FRONTEGG_ENCRYPTION_PASSWORD, `Hex string.\n\nFor quick password generation use the following command:\nnode -e "console.log(crypto.randomBytes(32).toString('hex'))"`);
    }
    return (0, _helpers.normalizeStringPasswordToMap)(encryptionPasswordEnv);
  }
  get isSSL() {
    return new URL(this.appUrl).protocol === 'https:';
  }
  get isHostedLogin() {
    var _this$fronteggAppOpti3;
    return (_this$fronteggAppOpti3 = this.fronteggAppOptions.hostedLoginBox) != null ? _this$fronteggAppOpti3 : (0, _helpers.getEnvOrDefault)(_constants.EnvVariables.FRONTEGG_HOSTED_LOGIN, 'false') === 'true';
  }
  get disableInitialPropsRefreshToken() {
    const disableInitialPropsRefreshToken = (0, _helpers.getEnvOrDefault)(_constants.EnvVariables.DISABLE_INITIAL_PROPS_REFRESH_TOKEN, setupEnvVariables.DISABLE_INITIAL_PROPS_REFRESH_TOKEN);
    return disableInitialPropsRefreshToken === 'true';
  }
  get appEnvConfig() {
    const config = {
      envAppUrl: this.appUrl,
      envBaseUrl: this.baseUrl,
      envClientId: this.clientId,
      envAppId: this.appId,
      secureJwtEnabled: this.secureJwtEnabled,
      envHostedLoginBox: this.isHostedLogin
    };
    return config;
  }
  checkHostedLoginConfig(options) {
    // noinspection JSDeprecatedSymbols
    if ((options == null ? void 0 : options.hostedLoginBox) === undefined) {
      return;
    }
    // noinspection JSDeprecatedSymbols
    if (options.hostedLoginBox != this.isHostedLogin) {
      throw new Error('There is mismatch between FRONTEGG_HOSTED_LOGIN environment variable and withFronteggOptions, ' + 'please remove the hostedLoginBox from withFronteggOptions and use the FRONTEGG_HOSTED_LOGIN environment variable instead.');
    }
  }
}
var _default = exports.default = new Config();
//# sourceMappingURL=index.js.map