import type { IncomingMessage } from 'http';
import { FronteggEdgeSession, FronteggNextJSSession } from '../types';
import { type NextRequest, NextResponse } from 'next/server';
export type HandleSessionOnEdge = {
    request: IncomingMessage | Request;
    pathname: string;
    headers: NextRequest['headers'];
    searchParams: URLSearchParams;
};
export declare const handleSessionOnEdge: (params: HandleSessionOnEdge) => Promise<NextResponse>;
/**
 * getSessionOnEdge is deprecated, please use handleSessionOnEdge instead example:
 *
 * ```ts
 *   import { NextRequest } from 'next/server';
 *   import { handleSessionOnEdge } from '@frontegg/nextjs/edge';
 *
 *   export const middleware = async (request: NextRequest) => {
 *     const { pathname, searchParams } = request.nextUrl;
 *     const headers = request.headers;
 *
 *     // Additional logic if needed
 *
 *     return handleSessionOnEdge({ request, pathname, searchParams, headers });
 *   };
 *
 *   export const config = {
 *     matcher: '/(.*)',
 *   };
 * ```
 * @deprecated
 */
export declare const getSessionOnEdge: (req: IncomingMessage | Request, disableWarning?: boolean) => Promise<FronteggNextJSSession | undefined>;
/**
 * Check session on edge and return session if exists this method does not redirect to login page
 * Example:
 *
 * ```ts
 *   import { NextRequest } from 'next/server';
 *   import { handleSessionOnEdge } from '@frontegg/nextjs/edge';
 *
 *   export const middleware = async (request: NextRequest) => {
 *     const { pathname, searchParams } = request.nextUrl;
 *     const headers = request.headers;
 *
 *     // Additional logic if needed
 *
 *     // check if it's a hosted login callback
 *     if (isHostedLoginCallback(pathname, searchParams)) {
 *       return handleHostedLoginCallback(request, pathname, searchParams);
 *     }
 *
 *     // check if we should bypass the middleware
 *     if (shouldByPassMiddleware(pathname)) {
 *       return NextResponse.next();
 *     }
 *
 *     // check session
 *     const session = await checkSessionOnEdge(request);
 *
 *     if (!session) {
 *       return redirectToLogin(pathname);
 *     }
 *
 *     // if headers are present forward them to the next response / request
 *     if (session.headers) {
 *        return NextResponse.next({
 *          headers: edgeSession.headers,
 *          request:{
 *            headers: edgeSession.forwardedHeaders
 *          }
 *        });
 *     }
 *     return NextResponse.next();
 *   };
 * ```
 *
 *
 * @param req
 */
export declare const checkSessionOnEdge: (req: IncomingMessage | Request) => Promise<FronteggEdgeSession | undefined>;
export declare const handleHostedLoginCallback: (req: IncomingMessage | Request, pathname: string, searchParams: URLSearchParams) => Promise<NextResponse>;
export declare const isHostedLoginCallback: (pathname: string, searchParams: URLSearchParams) => boolean;
