"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createSessionFromAccessTokenOnEdge = createSessionFromAccessTokenOnEdge;
exports.refreshAccessTokenIfNeededOnEdge = refreshAccessTokenIfNeededOnEdge;
var _cookies = _interopRequireDefault(require("../utils/cookies"));
var _config = _interopRequireDefault(require("../config"));
var _api = _interopRequireDefault(require("../api"));
var _fronteggLogger = _interopRequireDefault(require("../utils/fronteggLogger"));
var _jwt = _interopRequireDefault(require("../utils/jwt"));
var _encryptionEdge = _interopRequireDefault(require("../utils/encryption-edge"));
const logger = _fronteggLogger.default.child({
  tag: 'EdgeRuntime.refreshAccessTokenIfNeededOnEdge'
});
async function refreshAccessTokenIfNeededOnEdge(req) {
  var _ref, _ref2, _response$headers$raw, _response$headers, _response$headers$raw2, _response$headers2, _response$headers2$ge, _response$headers3, _response$headers3$ge, _CookieManager$modify, _data$accessToken;
  const refreshCookie = _cookies.default.getRefreshCookieFromRequestEdge(req);
  if (!refreshCookie) {
    logger.info('No refresh cookie found, No session found');
    return undefined;
  }
  logger.info('going to refresh token');
  const reqHeaders = req.headers;
  const headers = {};
  reqHeaders.forEach((value, key) => {
    headers[key] = value;
  });
  const clientId = _config.default.clientId;
  const clientSecret = _config.default.clientSecret;
  let response;
  try {
    if (_config.default.isHostedLogin) {
      response = await _api.default.refreshTokenHostedLogin(headers, refreshCookie, clientId, clientSecret);
    } else {
      response = await _api.default.refreshTokenEmbedded(headers);
    }
  } catch (e) {
    logger.error('Failed to refresh token', e);
    return undefined;
  }
  const isSecured = _config.default.isSSL;
  if (response === null || !response.ok) {
    const cookiesToRemove = _cookies.default.getRequestCookiesHeaderToRemove({
      cookieDomain: _config.default.cookieDomain,
      isSecured,
      req
    });
    if (cookiesToRemove) {
      return {
        session: undefined,
        headers: {
          'set-cookie': cookiesToRemove.join(', ')
        }
      };
    }
    return undefined;
  }
  const data = await response.json();
  const cookieHeader = // @ts-ignore the first argument "raw" will only work before nextjs 13.4 and the second argument "getSetCookie" will only work after
  (_ref = (_ref2 = (_response$headers$raw = (_response$headers = response.headers) == null || (_response$headers$raw2 = _response$headers.raw) == null ? void 0 : _response$headers$raw2.call(_response$headers)['set-cookie']) != null ? _response$headers$raw : // @ts-ignore the first argument "raw" will only work before nextjs 13.4 and the second argument "getSetCookie" will only work after
  (_response$headers2 = response.headers) == null || (_response$headers2$ge = _response$headers2.getSetCookie) == null ? void 0 : _response$headers2$ge.call(_response$headers2)) != null ? _ref2 : (_response$headers3 = response.headers) == null || (_response$headers3$ge = _response$headers3.get) == null ? void 0 : _response$headers3$ge.call(_response$headers3, 'set-cookie')) != null ? _ref : [];
  const newSetCookie = (_CookieManager$modify = _cookies.default.modifySetCookie(cookieHeader, isSecured)) != null ? _CookieManager$modify : [];
  const [session, decodedJwt, refreshToken] = await createSessionFromAccessTokenOnEdge(data);
  if (!session) {
    return {
      session: undefined,
      headers: {
        'set-cookie': newSetCookie.join(', ')
      }
    };
  }
  const cookieValue = _cookies.default.create({
    value: session,
    expires: new Date(decodedJwt.exp * 1000),
    secure: isSecured,
    req
  });
  newSetCookie.push(...cookieValue);
  const forwardedHeaders = req.headers;
  newSetCookie.forEach(cookie => {
    // get cookie name and value only
    const [name, value] = cookie.split(';')[0].split('=');
    forwardedHeaders.set('cookie', `${name}=${value}`);
  });
  return {
    session: {
      accessToken: (_data$accessToken = data.accessToken) != null ? _data$accessToken : data.access_token,
      user: decodedJwt,
      refreshToken
    },
    headers: {
      'set-cookie': newSetCookie.join(', ')
    },
    forwardedHeaders
  };
}
async function createSessionFromAccessTokenOnEdge(data) {
  var _data$accessToken2, _data$refreshToken;
  const accessToken = (_data$accessToken2 = data.accessToken) != null ? _data$accessToken2 : data.access_token;
  const refreshToken = (_data$refreshToken = data.refreshToken) != null ? _data$refreshToken : data.refresh_token;
  const {
    payload: decodedJwt
  } = await _jwt.default.verify(accessToken);
  decodedJwt.expiresIn = Math.floor((decodedJwt.exp * 1000 - Date.now()) / 1000);
  const tokens = {
    accessToken,
    refreshToken
  };
  const session = await _encryptionEdge.default.sealTokens(tokens, decodedJwt.exp);
  return [session, decodedJwt, refreshToken];
}
//# sourceMappingURL=refreshAccessTokenIfNeededOnEdge.js.map