import type { NextRequest } from 'next/server';
interface ByPassOptions {
    bypassStaticFiles?: boolean;
    bypassImageOptimization?: boolean;
    bypassHeaderRequests?: boolean;
}
/**
 * Use `shouldByPassMiddleware` in the middleware.ts file
 * to protect all application's routes.
 * You can override whitelist by passing options parameter
 * NOTE: this will slow down your application due to session check on each
 * static files and image request
 *
 * The default whitelist:
 * - _next/static (static files)
 * - _next/image (image optimization files)
 * - favicon.ico (favicon file)
 * - api/frontegg (API frontegg middleware)
 * - account/[login|logout|saml/callback|...] (frontegg authentication routes)
 */
export declare const shouldByPassMiddleware: (pathname: string, headers: NextRequest['headers'], options?: ByPassOptions) => boolean;
export {};
