"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FronteggApiMiddleware = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _FronteggProxy = require("./FronteggProxy");
var _constants = require("./constants");
var _helpers = require("./helpers");
var _pages = require("../pages");
var _config = _interopRequireDefault(require("../config"));
var _cookies = _interopRequireDefault(require("../utils/cookies"));
var _common = require("../common");
const middlewarePromise = (req, res) => new Promise(async resolve => {
  var _req$url;
  const fronteggUrlPath = (0, _helpers.rewritePath)((_req$url = req.url) != null ? _req$url : '/', _constants.fronteggPathRewrite);
  const rewriteUrl = (0, _helpers.rewritePath)(fronteggUrlPath != null ? fronteggUrlPath : '/', _constants.fronteggSSOPathRewrite);
  req.url = rewriteUrl;
  res.on('close', () => resolve());
  const options = {
    target: process.env['FRONTEGG_BASE_URL']
  };
  if (process.env['FRONTEGG_TEST_URL'] && req.url == '/frontegg/middleware-test') {
    options.target = process.env['FRONTEGG_TEST_URL'];
  }
  const headers = {};
  if (process.env['FRONTEGG_SECURE_JWT_ENABLED'] === 'true') {
    const session = await (0, _pages.getSession)(req);
    if (session != null && session.accessToken) {
      headers['authorization'] = 'Bearer ' + session.accessToken;
    }
  }
  if (_config.default.isHostedLogin && (0, _helpers.isFronteggLogoutUrl)(req.url || '') && !headers['authorization']) {
    const sessionCookie = _cookies.default.getSessionCookieFromRequest(req);
    const tokens = await (0, _common.getTokensFromCookie)(sessionCookie);
    if (tokens != null && tokens.accessToken) {
      headers['authorization'] = 'Bearer ' + tokens.accessToken;
    }
  }
  _FronteggProxy.FronteggProxy.web(req, res, (0, _extends2.default)({}, options, {
    headers
  }));
});

/**
 * Next.js HTTP Proxy Middleware
 * @see https://nextjs.org/docs/api-routes/api-middlewares
 * @param {NextApiRequest} req - NextJS api request passed from api routing
 * @param {NextApiResponse} res - NextJS api response passed from api routing
 */
const FronteggApiMiddleware = async (req, res) => {
  return await middlewarePromise(req, res);
};
exports.FronteggApiMiddleware = FronteggApiMiddleware;
FronteggApiMiddleware.cors = options => async (req, res) => {
  var _req$headers$host;
  const {
    allowedOrigins = ['*'],
    allowedMethods = ['GET', 'POST', 'PUT', 'DELETE', 'PATCH', 'OPTIONS'],
    allowedHeaders = ['Content-Type', 'Authorization'],
    allowCredentials = true
  } = options;
  if ((0, _helpers.isInternalRequest)((_req$headers$host = req.headers.host) != null ? _req$headers$host : '')) {
    var _req$headers$origin;
    const origin = (_req$headers$origin = req.headers.origin) != null ? _req$headers$origin : '';
    const combinedHeaders = Array.from(new Set([..._constants.defaultFronteggHeaders, ...allowedHeaders]));
    if (allowedOrigins.includes(origin)) {
      res.setHeader('Access-Control-Allow-Origin', origin);
    } else {
      res.removeHeader('Access-Control-Allow-Origin');
    }
    res.setHeader('Access-Control-Allow-Methods', allowedMethods.join(','));
    res.setHeader('Access-Control-Allow-Headers', combinedHeaders.join(','));
    res.setHeader('Access-Control-Allow-Credentials', allowCredentials ? 'true' : 'false');
  }
  return middlewarePromise(req, res);
};
//# sourceMappingURL=FronteggApiMiddleware.js.map