"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.rewritePath = exports.removeJwtSignatureFrom = exports.isInternalRequest = exports.isFronteggOauthLogoutUrl = exports.isFronteggLogoutUrl = exports.getHostedLogoutUrl = exports.extractAccessToken = void 0;
var _urls = require("../api/urls");
var _config = _interopRequireDefault(require("../config"));
var _routing = require("../utils/routing");
/**
 * If pattern information matching the input url information is found in the `pathRewrite` array,
 * the url value is partially replaced with the `pathRewrite.replaceStr` value.
 * @param url
 * @param pathRewrite
 */
const rewritePath = (url, pathRewrite) => {
  if (Array.isArray(pathRewrite)) {
    for (const item of pathRewrite) {
      const {
        patternStr,
        replaceStr
      } = item;
      const pattern = RegExp(patternStr);
      if (pattern.test(url)) {
        return url.replace(pattern, replaceStr);
      }
    }
  } else {
    for (const patternStr in pathRewrite) {
      const pattern = RegExp(patternStr);
      const path = pathRewrite[patternStr];
      if (pattern.test(url)) {
        return url.replace(pattern, path);
      }
    }
  }
  return url;
};

/**
 * Checks If route is a logout route
 * @param url
 */
exports.rewritePath = rewritePath;
const isFronteggLogoutUrl = url => url.endsWith('/logout');

/**
 * Checks If route is a hosted logout route
 * @param url
 */
exports.isFronteggLogoutUrl = isFronteggLogoutUrl;
const isFronteggOauthLogoutUrl = url => url.endsWith('/oauth/logout');

/**
 * Returns url to be redirected for hosted logout
 * @param referer the route to redirect to after logout
 */
exports.isFronteggOauthLogoutUrl = isFronteggOauthLogoutUrl;
const getHostedLogoutUrl = (referer = _config.default.appUrl) => {
  var _config$authRoutes$lo, _config$authRoutes;
  const logoutPath = (_config$authRoutes$lo = (_config$authRoutes = _config.default.authRoutes) == null ? void 0 : _config$authRoutes.logoutUrl) != null ? _config$authRoutes$lo : _routing.defaultFronteggRoutes.logoutUrl;
  const refererUrl = new URL(referer);
  const isLogoutRoute = refererUrl.toString().includes(logoutPath);
  const redirectUrl = isLogoutRoute ? refererUrl.origin + refererUrl.search : refererUrl.toString();
  return (0, _urls.buildLogoutRoute)(redirectUrl, _config.default.baseUrl);
};
exports.getHostedLogoutUrl = getHostedLogoutUrl;
/**
 * Extracts the access token from the response body
 * @param bodyStr
 */
const extractAccessToken = bodyStr => {
  const body = JSON.parse(bodyStr);
  if (body.authResponse) {
    Object.assign(body, body.authResponse);
  }
  return {
    accessToken: body.accessToken || body.access_token,
    refreshToken: body.refreshToken || body.refresh_token
  };
};
exports.extractAccessToken = extractAccessToken;
const jwtKeys = ['accessToken', 'access_token', 'idToken', 'id_token'];
const refreshTokenKeys = ['refreshToken', 'refresh_token'];
/**
 * Removes the signature from the JWT token
 * @param body
 */
const removeJwtSignatureFrom = body => {
  if (!body) {
    return body;
  }
  if (body.authResponse) {
    jwtKeys.forEach(key => {
      if (body.authResponse[key]) {
        // body.authResponse[key] = "REDACTED_FOR_SECURITY";
        // body.authResponse[key] = body.authResponse[key].split('.')[0] + '.' + body.authResponse[key].split('.')[1];
        body.authResponse[key] = `REDACTED_FOR_SECURITY.${body.authResponse[key].split('.')[1]}.REDACTED_FOR_SECURITY`;
      }
    });
    refreshTokenKeys.forEach(key => {
      if (body.authResponse[key]) {
        delete body.authResponse[key];
      }
    });
  }
  jwtKeys.forEach(key => {
    if (body[key]) {
      // body[key] = "REDACTED_FOR_SECURITY";
      // body[key] = body[key].split('.')[0] + '.' + body[key].split('.')[1];
      body[key] = `REDACTED_FOR_SECURITY.${body[key].split('.')[1]}.REDACTED_FOR_SECURITY`;
    }
  });
  refreshTokenKeys.forEach(key => {
    if (body[key]) {
      delete body[key];
    }
  });
  return body;
};
exports.removeJwtSignatureFrom = removeJwtSignatureFrom;
const isInternalRequest = host => _config.default.appUrl.includes(host);
exports.isInternalRequest = isInternalRequest;
//# sourceMappingURL=helpers.js.map