"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getSession = void 0;
exports.withSSRSession = withSSRSession;
var _routing = require("../utils/routing");
var _config = _interopRequireDefault(require("../config"));
var _cookies = _interopRequireDefault(require("../utils/cookies"));
var _createSession = _interopRequireDefault(require("../utils/createSession"));
var _encryption = _interopRequireDefault(require("../utils/encryption"));
var _helpers = require("../utils/refreshAccessTokenIfNeeded/helpers");
const getSession = (req, res) => {
  if (res && (0, _helpers.hasSetSessionCookie)(res.getHeader('set-cookie'))) {
    const cookies = _cookies.default.getSessionCookieFromRedirectedResponse(res);
    return (0, _createSession.default)(cookies, _encryption.default);
  }
  const cookies = _cookies.default.getSessionCookieFromRequest(req);
  return (0, _createSession.default)(cookies, _encryption.default);
};
exports.getSession = getSession;
function withSSRSession(handler) {
  return async context => {
    const session = await getSession(context.req, context.res);
    if (session) {
      return handler(context, session);
    } else {
      var _config$authRoutes$lo, _context$resolvedUrl;
      let loginUrl = (_config$authRoutes$lo = _config.default.authRoutes.loginUrl) != null ? _config$authRoutes$lo : _routing.defaultFronteggRoutes.loginUrl;
      if (!loginUrl.startsWith('/')) {
        loginUrl = `/${loginUrl}`;
      }
      const fullUrl = new URL(_config.default.appUrl + context.resolvedUrl);
      const urlSearchParams = fullUrl.searchParams;
      urlSearchParams.set('redirectUrl', (_context$resolvedUrl = context.resolvedUrl) != null ? _context$resolvedUrl : context.req.url);
      return {
        redirect: {
          permanent: false,
          destination: `${loginUrl}?${urlSearchParams.toString()}`
        },
        props: {}
      };
    }
  };
}
//# sourceMappingURL=helpers.js.map