import { CookieSerializeOptions, RequestType } from './types';
import { ServerResponse } from 'http';
/**
 * Return a cookieName with index, used for divided cookies.
 *
 * @param {number} index - The index of the cookie, starts with '1'
 * @param {string} _cookieName - Default is {@link config.cookieName}
 */
export declare const getIndexedCookieName: (index: number, _cookieName?: string) => string;
/**
 * Split cookie value if value length exceeded the MAX Length of a standard HTTP header.
 * Used to split the session cookie.
 *
 * @param {string} cookieName - Cookie name for serializing
 * @param {string} value - cookie value to split if needed
 * @param {CookieSerializeOptions} options - {@link CookieSerializeOptions} for serializing
 */
export declare const splitValueToChunks: (cookieName: string, value: string, options: CookieSerializeOptions) => string[];
/**
 * Receive incoming http request, and extract the cookie header.
 * @return cookie as string if exists, else empty string
 *
 * @param {RequestType} request - Incoming HTTP Request
 */
export declare const getCookieHeader: (request: RequestType) => string;
/**
 * Receive http response, and extract the set-cookie header.
 * @return cookie as string if exists, else empty string
 *
 * @param {ResponseType} response - HTTP Response
 */
export declare const getSetCookieHeader: (response: ServerResponse) => string;
export declare const getRefreshTokenCookieNameVariants: () => string[];
