import type { RequestCookie } from 'next/dist/server/web/spec-extension/cookies';
import { CreateCookieOptions, RemoveCookiesOptions, RequestType, ResponseType } from './types';
declare class CookieManager {
    getCookieName: (cookieNumber?: number, cookieName?: string) => string;
    get refreshTokenKey(): string;
    /**
     * This function creates list of empty cookies that already exists in the request.
     * This is used for removing existing cookies before creating new ones.
     * @param {CreateCookieOptions} options - Create cookie options
     */
    getEmptyCookiesBeforeCreatingNew({ req, value, secure, domain }: CreateCookieOptions, newCookies: string[]): string[];
    /**
     * Validate and create new cookie headers.
     * The default value of `cookieName` is {@link config.cookieName}
     * @param {CreateCookieOptions} options - Create cookie options
     */
    create(options: CreateCookieOptions): string[];
    /**
     * Receive incoming http request, and extract the cookie header.
     * @return cookie as string if exists, else empty string
     *
     * @param {RequestType} request - Incoming HTTP Request
     */
    parseCookieHeader(request: RequestType): Record<string, string>;
    /**
     * Loop over cookie headers, extract, parse cookies and merged divided cookies from incoming http request,
     * @return full session cookie headers if exists, else return undefined
     * @param {RequestType} request - Incoming HTTP Request
     */
    getSessionCookieFromRequest(request?: RequestType): string | undefined;
    getRefreshCookieFromRequestEdge(request?: RequestType): string | undefined;
    /**
     * Loop over cookie headers, extract, parse cookies and merged divided cookies from redirected http response,
     * @return full session cookie headers if exists, else return undefined
     * @param {ResponseType} response - Outgoing HTTP response
     */
    getSessionCookieFromRedirectedResponse(response?: ResponseType): string | undefined;
    parseCookieFromArray(cookies: RequestCookie[]): string | undefined;
    private createEmptySingleCookie;
    createEmptyCookies: (isSecured: boolean, cookieDomain: string, _cookiesToRemove: string[], removeRefresh?: boolean) => string[];
    private getCookiesToRemove;
    /**
     * Take a list of cookieNames and return the headers to remove the cookies from the client side
     * @param {RemoveCookiesOptions} setCookieValue
     */
    getRequestCookiesHeaderToRemove({ cookieNames, isSecured, cookieDomain, req, }: Omit<RemoveCookiesOptions, 'res'>): string[];
    /**
     * Take a list of cookieNames and modify request/response headers
     * to proxy the cookies from Next.js to Frontegg Services and vice-versa
     * @param {RemoveCookiesOptions} setCookieValue
     */
    removeCookies({ cookieNames, isSecured, cookieDomain, res, req }: RemoveCookiesOptions): void;
    /**
     * Take a list of cookie headers and modify the Domain / Secure / SameSite
     * to proxy the cookies to Frontegg Services and vice-versa
     * @param {string[]} setCookieValue - list of cookies to modify
     * @param {boolean} isSecured - if the running application behind SSL
     */
    modifySetCookie: (setCookieValue: string[] | undefined, isSecured: boolean) => string[] | undefined;
}
declare const _default: CookieManager;
export default _default;
