"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = createSession;
var _jwt = _interopRequireDefault(require("../jwt"));
var _fronteggLogger = _interopRequireDefault(require("../fronteggLogger"));
async function createSession(cookie, encryption) {
  const logger = _fronteggLogger.default.child({
    tag: 'SessionCreator.createSession'
  });
  logger.info('Creating new session');
  try {
    if (!cookie) {
      logger.info('no cookies');
      return undefined;
    }
    logger.debug('decrypting Session cookie');
    const tokens = await encryption.unsealTokens(cookie);
    if (!(tokens != null && tokens.accessToken)) {
      logger.info('no accessToken in session');
      return undefined;
    }
    const {
      accessToken,
      refreshToken
    } = tokens;
    logger.debug('Going to verify accessToken');
    const {
      payload
    } = await _jwt.default.verify(accessToken);
    logger.debug('Access token verified successfully');
    const session = {
      accessToken,
      user: payload,
      refreshToken
    };
    logger.debug('Check if access token will expire soon');
    if (session.user.exp * 1000 < Date.now()) {
      return undefined;
    }
    logger.info('Successfully create session object');
    return session;
  } catch (e) {
    logger.error('Failed to create session', e);
    return undefined;
  }
}
//# sourceMappingURL=index.js.map