"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = fetchUserData;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _api = require("../../api");
var _common = require("../common");
var _fronteggLogger = _interopRequireDefault(require("../fronteggLogger"));
var _config = _interopRequireDefault(require("../../config"));
var _utils = require("../../api/utils");
const FULFILLED_STATUS = 'fulfilled';
async function fetchUserData(options) {
  const {
    getSession,
    getHeaders
  } = options;
  const logger = _fronteggLogger.default.child({
    tag: 'fetchUserData.getAllUserData'
  });
  try {
    const session = await getSession();
    if (!session) {
      logger.info('No session found');
      return {};
    }
    const {
      accessToken
    } = session;
    const reqHeaders = await getHeaders();
    const headers = (0, _extends2.default)({}, reqHeaders, {
      authorization: `Bearer ${accessToken}`
    });
    if (_config.default.appId) {
      headers[_utils.FRONTEGG_APPLICATION_ID_HEADER] = _config.default.appId;
    }
    if (_config.default.shouldForwardIp) {
      logger.debug('Retrieving forwarded IP...');
      const clientIp = (0, _utils.getClientIp)(reqHeaders['cf-connecting-ip'] || reqHeaders['x-vercel-proxied-for'] || reqHeaders['x-real-ip'] || reqHeaders['x-forwarded-for']);
      if (clientIp) {
        headers[_utils.FRONTEGG_FORWARD_IP_HEADER] = clientIp;
      }
    }
    logger.debug('Retrieving user data...');
    const [baseUserResult, tenantsResult, entitlementsResult, meAuthorizationResult] = await Promise.allSettled([(0, _api.getMe)(headers), (0, _api.getTenants)(headers), (0, _api.getEntitlements)(headers), (0, _api.getMeAuthorization)(headers)]);
    logger.debug('Retrieved user data:', 'baseUserResult: ', baseUserResult.status, 'tenantsResult:', tenantsResult.status, 'entitlements:', entitlementsResult.status);
    const baseUser = baseUserResult.status === FULFILLED_STATUS ? baseUserResult.value : null;
    const tenantsResponse = tenantsResult.status === FULFILLED_STATUS ? tenantsResult.value : null;
    const meAuthorizationResponse = meAuthorizationResult.status === FULFILLED_STATUS ? meAuthorizationResult.value : null;
    const entitlementsResponse = entitlementsResult.status === FULFILLED_STATUS ? entitlementsResult.value : undefined;
    if (!baseUser || !tenantsResponse) {
      logger.info('No base user or tenants found');
      return {};
    }
    const user = (0, _extends2.default)({}, session.user, baseUser, meAuthorizationResponse, {
      entitlements: entitlementsResponse,
      expiresIn: (0, _common.calculateExpiresInFromExp)(session.user.exp)
    });
    logger.info('Retrieved all user data successfully');
    const {
      tenants,
      activeTenant
    } = tenantsResponse;
    return {
      user,
      session,
      tenants,
      activeTenant
    };
  } catch (e) {
    // logger.error(e.message, e);
    return {};
  }
}
//# sourceMappingURL=index.js.map