"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _constants = require("./constants");
/**
 * @see [enabling-debug-logging](https://docs.github.com/en/actions/monitoring-and-troubleshooting-workflows/enabling-debug-logging)
 * in GitHub actions in failed tests for more debugging logs
 */
const isGithubRunnerDebugMode = process.env.ACTIONS_STEP_DEBUG === 'true' || process.env.ACTIONS_RUNNER_DEBUG === 'true';
let logLevel = 'warn';
if (process.env.FRONTEGG_LOG_LEVEL) {
  logLevel = process.env.FRONTEGG_LOG_LEVEL;
}
if (isGithubRunnerDebugMode) {
  logLevel = 'debug';
}
if (Object.keys(_constants.LEVEL_NAMES).indexOf(logLevel) === -1) {
  logLevel = 'warn';
}
const maxTagLength = 25;
function repeat(num) {
  return [...new Array(num)].map(() => ' ').join('');
}
class FronteggLogger {
  constructor(options) {
    var _options$level;
    this.tag = void 0;
    this.level = void 0;
    if (options.tag.length > maxTagLength) {
      this.tag = options.tag.slice(0, 7) + '...' + options.tag.slice(options.tag.length - maxTagLength + 10);
    } else {
      this.tag = repeat(maxTagLength - options.tag.length) + options.tag;
    }
    this.level = (_options$level = options.level) != null ? _options$level : logLevel;
  }
  prepare(printLevel, args) {
    const levelName = _constants.LEVELS[_constants.LEVEL_NAMES[printLevel]];
    return [new Date().toISOString(), `|${levelName}| ${this.tag}:`, ...args];
  }
  debug(...args) {
    if (_constants.LEVEL_NAMES[this.level] <= _constants.LEVEL_NAMES.debug) {
      console.log.apply(console, this.prepare('debug', args));
    }
  }
  info(...args) {
    if (_constants.LEVEL_NAMES[this.level] <= _constants.LEVEL_NAMES.info) {
      console.info.apply(console, this.prepare('info', args));
    }
  }
  warn(...args) {
    if (_constants.LEVEL_NAMES[this.level] <= _constants.LEVEL_NAMES.warn) {
      console.warn.apply(console, this.prepare('warn', args));
    }
  }
  error(...args) {
    console.error.apply(console, this.prepare('error', args));
  }
  static child(options) {
    return new FronteggLogger(options);
  }
}
var _default = exports.default = FronteggLogger;
//# sourceMappingURL=index.js.map