"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _js = require("@frontegg/js");
var _reduxStore = require("@frontegg/redux-store");
var _sdkVersion = _interopRequireDefault(require("../../sdkVersion"));
var _package = _interopRequireDefault(require("next/package.json"));
var _utils = require("../../api/utils");
var _urls = require("../common/urls");
const initializeFronteggApp = ({
  options,
  onRedirectTo,
  appName,
  storeHolder
}) => {
  var _options$authOptions, _options$authOptions2, _options$hostedLoginB, _options$authOptions$, _options$authOptions3;
  const {
    session,
    user,
    tenants,
    activeTenant
  } = options;
  const {
    accessToken,
    refreshToken
  } = session != null ? session : {};
  const contextOptions = (0, _extends2.default)({
    requestCredentials: 'include'
  }, options.contextOptions, {
    additionalHeadersResolver: async () => {
      var _options$contextOptio;
      const additionalHeaders = [];
      const originalAdditionalHeadersResolver = (_options$contextOptio = options.contextOptions) == null ? void 0 : _options$contextOptio.additionalHeadersResolver;
      if (typeof originalAdditionalHeadersResolver === 'function') {
        try {
          additionalHeaders.push(...(await originalAdditionalHeadersResolver()));
        } catch (e) {
          /** ignore failed additionalHeadersResolver */
        }
      } else if (Array.isArray(originalAdditionalHeadersResolver)) {
        additionalHeaders.push(...originalAdditionalHeadersResolver);
      }
      additionalHeaders.push({
        key: 'x-frontegg-framework',
        value: `next@${_package.default.version}`
      });
      additionalHeaders.push({
        key: 'x-frontegg-sdk',
        value: `@frontegg/nextjs@${_sdkVersion.default.version}`
      });
      return additionalHeaders;
    },
    tokenResolver: options.secureJwtEnabled ? () => '' : undefined,
    baseUrl: path => {
      if ((0, _utils.isMiddlewarePath)(path) || options.secureJwtEnabled) {
        return `${options.envAppUrl}/api`;
      } else {
        return options.envBaseUrl;
      }
    },
    beforeRequestInterceptor: (reqOptions, url) => {
      /**
       * Determines whether the authorization header should be removed from a request.
       * @param {String} urlStr - The URL of the request.
       */
      try {
        if (url && reqOptions.headers) {
          const {
            pathname,
            origin
          } = new URL(url);
          if (typeof window !== 'undefined' && origin !== window.location.origin) {
            return (0, _extends2.default)({}, reqOptions, {
              url
            });
          }
          const excludedPaths = [_urls.CommonUrls.refreshToken.embedded, _urls.CommonUrls.refreshToken.hosted, _urls.CommonUrls.activateAccount.activate, _urls.CommonUrls.logout];
          if (excludedPaths.some(path => pathname.endsWith(path))) {
            delete reqOptions.headers['authorization'];
            delete reqOptions.headers['Authorization'];
          }
        }
      } catch (e) {
        /** ignore */
      }
      return (0, _extends2.default)({}, reqOptions, {
        url
      });
    },
    clientId: options.envClientId,
    appId: options.envAppId
  });
  const tenantsState = (0, _extends2.default)({
    tenants: tenants || [],
    activeTenant
  }, (_options$authOptions = options.authOptions) == null ? void 0 : _options$authOptions.tenantsState);
  const userData = user ? (0, _extends2.default)({}, user, {
    accessToken: accessToken != null ? accessToken : '',
    refreshToken: refreshToken != null ? refreshToken : undefined
  }, (_options$authOptions2 = options.authOptions) == null ? void 0 : _options$authOptions2.user) : null;
  const authOptions = (0, _extends2.default)({}, options.authOptions, {
    onRedirectTo,
    isLoading: false,
    isAuthenticated: !!options.session,
    hostedLoginBox: (_options$hostedLoginB = options.hostedLoginBox) != null ? _options$hostedLoginB : false,
    disableSilentRefresh: (_options$authOptions$ = (_options$authOptions3 = options.authOptions) == null ? void 0 : _options$authOptions3.disableSilentRefresh) != null ? _options$authOptions$ : true,
    user: userData,
    tenantsState: tenantsState
  });
  let sharedStore = storeHolder.store;
  if (!sharedStore) {
    sharedStore = (0, _reduxStore.createStore)({
      context: contextOptions,
      storeHolder,
      previewMode: options.previewMode,
      name: appName != null ? appName : 'default',
      urlStrategy: options.urlStrategy,
      builderMode: false,
      initialState: {
        auth: authOptions
      }
    });
    storeHolder.store = sharedStore;
  }
  let createdApp;
  try {
    createdApp = _js.AppHolder.getInstance(appName != null ? appName : 'default');
    createdApp.store = sharedStore;
  } catch (e) {
    var _options$hostedLoginB2, _options$customLoginB;
    createdApp = (0, _js.initialize)((0, _extends2.default)({}, options, {
      store: sharedStore,
      hostedLoginBox: (_options$hostedLoginB2 = options.hostedLoginBox) != null ? _options$hostedLoginB2 : false,
      customLoginBox: (_options$customLoginB = options.customLoginBox) != null ? _options$customLoginB : false,
      basename: options.basename,
      authOptions,
      contextOptions,
      onRedirectTo
    }), appName != null ? appName : 'default');
  }
  return createdApp;
};
var _default = exports.default = initializeFronteggApp;
//# sourceMappingURL=index.js.map