"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _jose = require("jose");
var _api = _interopRequireDefault(require("../../api"));
var _fronteggLogger = _interopRequireDefault(require("../fronteggLogger"));
var _config = _interopRequireDefault(require("../../config"));
class JwtUtils {
  constructor() {
    this.publicKey = void 0;
  }
  /**
   * Get the JWT public key from Frontegg service
   * to verify user's access token when calling getSession
   * in getServerSideProps and ServerComponents
   * @private
   */
  async loadPublicKey() {
    const logger = _fronteggLogger.default.child({
      tag: 'JwtManager.loadPublicKey'
    });
    let publicKey;
    try {
      var _config$jwtPublicKeyJ;
      publicKey = JSON.parse((_config$jwtPublicKeyJ = _config.default.jwtPublicKeyJson) != null ? _config$jwtPublicKeyJ : '{}');
      logger.info('Public key loaded from env variable');
    } catch (e) {
      logger.info('Going to load public key from frontegg jwks');
      publicKey = await _api.default.loadPublicKey();
    }
    logger.info('Importing Public key into jose');
    this.publicKey = await (0, _jose.importJWK)(publicKey, publicKey.alg);
    return this.publicKey;
  }

  /**
   * Load public key from Frontegg services if not cached
   * @private
   */
  async getPublicKey() {
    if (this.publicKey === undefined) {
      return await this.loadPublicKey();
    }
    return this.publicKey;
  }

  /**
   * verify JWT token with current loaded public key from Frontegg services
   */
  async verify(jwt) {
    const publicKey = await this.getPublicKey();
    return await (0, _jose.jwtVerify)(jwt, publicKey);
  }
}
var _default = exports.default = new JwtUtils();
//# sourceMappingURL=index.js.map