import { IncomingMessage } from 'http';
import { FronteggNextJSSession } from '../../types';
export declare function hasRefreshTokenCookie(cookies: Record<string, any>): boolean;
export declare function refreshAccessTokenEmbedded(request: IncomingMessage): Promise<Response | null>;
export declare function refreshAccessTokenHostedLogin(request: IncomingMessage): Promise<Response | null>;
/**
 * If url starts with /_next/ means that the user trying to navigate
 * to a new nextjs page, in this scenario no need to refresh token
 * we can just return the actual stateless session from
 * the encrypted cookie
 */
export declare function isRuntimeNextRequest(url: string): boolean;
/**
 * If url starts with '/oauth/callback' means that the user navigated back
 * from frontegg hosted login, in this scenario no need to SSR refresh token
 */
export declare function isOauthCallback(url: string): boolean;
/**
 * If url starts with '/account/saml/callback' means that the user navigated back
 * from sso login, in this scenario no need to SSR refresh token
 */
export declare function isSamlCallback(url: string): boolean;
/**
 * If the url equals to '/frontegg/auth/{provider}/callback', it means that the SSO provider
 * is posting an http request to the nextjs backend middleware after successfully logged in the user
 */
export declare function isSSOPostRequest(url: string): boolean;
/**
 * This function verifies if the headers includes a 'set-cookie' header
 * from a prior refresh token request. If it's the case, we can infer that the
 * session cookie has been initialized, thus we can disable the double refresh token
 * for server-side redirects such as '/_error' or any other server-side redirects.
 */
export declare function hasSetSessionCookie(cookieHeader: number | string | string[] | undefined): boolean;
/**
 * This function stores the Frontegg session instance for use
 * within the Next.js application during the token refresh process
 * in the redirect request page.
 */
export declare function saveForwardedSession(holder: any, session: FronteggNextJSSession | undefined): void;
/**
 * This function retrieves the stored session from the previous redirected page request.
 * This helps in preventing the token from being refreshed twice during a single client page request.
 */
export declare function getForwardedSession(holder: any): FronteggNextJSSession | null;
